@@ -11,7 +11,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: misc.h,v 1.23 2002/05/16 15:06:45 doligez Exp $ */
+/* $Id: misc.h,v 1.24 2003/05/12 14:21:52 xleroy Exp $ */
 
 /* Miscellaneous macros and variables. */
 
@@ -44,7 +44,7 @@ typedef size_t asize_t;
 
 /* Export control (to mark primitives and to handle Windows DLL) */
 
-#if defined(_WIN32) && defined(_DLL)
+#if defined(_WIN32) && defined(CAML_DLL)
 # define CAMLexport __declspec(dllexport)
 # define CAMLprim __declspec(dllexport)
 # if defined(IN_OCAMLRUN)
